@@ -8,7 +8,7 @@ except ModuleNotFoundError:
     pass
 
 
-def tuple_from_XXX(obj):
+def XXX_serializejson(obj):
     """
     Args:
         obj:  the object to serialize.
